# dnx-data

This is the DNX data solution package.


## Setup

#### Dependencies
- Python 3

#### Python Virtual Environment
```bash
# Create environment
python3 -m venv env

# To activate the environment
source env/bin/activate

# When you finish you can exit typing
deactivate
```

#### Install and test module
```bash
#### Install dependencies and module
pip3 install --editable .
```

## Authors

Module managed by [DNX Solutions](https://github.com/DNXLabs).

## License

Apache 2 Licensed. See [LICENSE](https://github.com/DNXLabs/dnx-data/blob/master/LICENSE) for full details.

